import {ScrollView, Image, Swiper, SwiperItem, View} from "@tarojs/components";
import {CSSProperties, FC, useEffect, useMemo, useState} from "react";
import {Category, HomeApi} from "@/api";
import Taro from "@tarojs/taro";
import styles from './sort.module.scss'
import Tabs, {TabList} from "@/components/tabs/tabs";
import {illnessApi} from "@/api/illness";
import Empty from "@/components/empty/empty";
import leftArrow from "@/static/img/leftArrow.png"
import Spin from "@/components/spinner";
// import NavigationBar from "@/components/navigationBar/navigationBar";

const prefix = 'SORT'
const Sort: FC = () => {
  const [data, setData] = useState<Category[]>([])
  const [firstId, setFirstId] = useState<number | undefined>(undefined)  // 一级分类
  const [secondId, setSecondId] = useState<number | undefined>(undefined) // 二级分类
  const [list, setList] = useState<any[]>([])
  const [enable, setEnable] = useState(true)
  const [loading, setLoading] = useState(false)
  const globalData = Taro.getApp().globalData
  const menu = Taro.getMenuButtonBoundingClientRect()

  async function getData() {
    try {

      const res = await HomeApi.category(3)
      setData(res)
      if (res.length) {
        setFirstId(res[0].id)
        setSecondId(res[0]?.resource_category?.[0].id)
      }
    } catch (e) {
      setLoading(false)
    }
    setEnable(false)
  }

  function jump(id: number) {
    Taro.navigateTo({url: '/pages/preview/illness/list/list?id=' + id})
  }

  const getTabList = useMemo((): TabList[] => {
    return data.map<TabList>(d => ({
      title: d.name,
      value: d.id
    }))
  }, [data])

  const headerStyles: CSSProperties = {
    paddingTop: globalData.statusBarHeight + 'px',
    display: 'flex',
    alignItems: "center",
    width: menu.left - 10 + 'px',
  }

  function firstIdChange(id: number) {
    setFirstId(id)
    const resource_category = data.find(d => d.id === id)?.resource_category
    setSecondId(resource_category?.[0]?.id)
  }

  Taro.useLoad(getData)

  useEffect(() => {
    if (secondId) {
      setLoading(true)
      illnessApi.list(secondId, 1, 100).then(res => {
        setList(res.list)
      }).catch(() => {
        setList([])
      })
    } else {
      setList([])
    }
    setLoading(false)
  }, [secondId])

  function swiperChange(e) {
    const firstData = data[e.target.current]
    if (!firstData) return;
    setFirstId(firstData.id)
    setSecondId(firstData?.resource_category?.[0]?.id)
  }

  return (
    <View>
      <Spin enable={enable} overlay/>
      <View style={headerStyles}>
        <View
          className="flex flex-column align-center justify-center"
          style={{width:globalData.textBarHeight+'px', height: globalData.textBarHeight+'px'}}
          onClick={() => Taro.navigateBack()}
        >
          <Image
            src={leftArrow}
            mode='widthFix'
            className={styles.back}
          />
        </View>
        <View className="flex">
          <Tabs
            tabList={getTabList}
            current={firstId}
            onChange={(data) => firstIdChange(data.tab?.value as number)}
          />
          <View className="flex-1" />
        </View>
      </View>

      {/*<Search onConfirm={onConfirm}/>*/}

      <Swiper
        onChange={swiperChange}
        className={styles.scrollView}
        current={data.findIndex(d => d.id === firstId)}
        style={{top: `${globalData.statusBarHeight + 59}px`}}>
        {
          data.map(d => <SwiperItem key={d.id} className='flex'>
            <ScrollView scrollY className={styles.firstOrder} enhanced showScrollbar={false}>
              {
                d.resource_category?.map(d => <View
                  id={`${prefix}-${d.id}`}
                  key={d.id}
                  onClick={() => setSecondId(d.id)}
                  className={secondId === d.id && styles.select}>
                  {d.name}
                </View>)
              }
            </ScrollView>

            <ScrollView
              enhanced
              showScrollbar={false}
              scrollY
              className={styles.tree}
              scrollWithAnimation>
              {
                loading ? <Spin enable={loading}/> : <>
                  {
                    list.length ?
                      list.map(d => <View className={styles.list} onClick={() => jump(d.id)}>{d.name}</View>)
                      : <Empty name='暂无数据'/>
                  }
                </>
              }
            </ScrollView>
          </SwiperItem>)
        }
      </Swiper>
    </View>
  )
}

export default Sort
